@@ -10,27 +10,26 @@ SPVM::Integer - Integer Utility
 
 =head2 MIN_VALUE
 
-B<int MIN_VALUE()>
+B<sub MIN_VALUE() : int>
 
 A constant holding the minimum value a int can have, C<-2147483648>.
 
 =head2 MAX_VALUE
 
-B<int MAX_VALUE()>
+B<sub MAX_VALUE() : int>
 
 A constant holding the maximum value a int can have, C<2147483647>.
 
-=head2 SIZE
-
-B<int SIZE>
-
-The number of bits used to represent a int value in two's complement binary form.
-
 =head2 BYTES
 
-B<int BYTES()>
+B<sub BYTES() : int>
 
-The number of ints used to represent a int value in two's complement binary form.
+The number of ints used to represent a int value in two's complement binary form, C<4>.
+
+=head2 SIZE
+
+B<sub SIZE() : int>
+
+The number of bits used to represent a int value in two's complement binary form, C<32>.
 
-=head1 FUNCTIONS
 
