@@ -6,31 +6,28 @@ package SPVM::Short;
 
 SPVM::Short - Short Utility
 
-=head1 CONSTANT FUNCTIONS
+=head1 FUNCTIONS
 
 =head2 MIN_VALUE
 
-B<short MIN_VALUE()>
+B<sub MIN_VALUE() : short>
 
 A constant holding the minimum value a short can have, C<-32768>.
 
 =head2 MAX_VALUE
 
-B<short MAX_VALUE()>
+B<sub MAX_VALUE() : short>
 
 A constant holding the maximum value a short can have, C<32767>.
 
-=head2 SIZE
-
-B<int SIZE>
-
-The number of bits used to represent a short value in two's complement binary form.
-
 =head2 BYTES
 
-B<int BYTES()>
+B<sub BYTES() : int>
 
-The number of shorts used to represent a short value in two's complement binary form.
+The number of shorts used to represent a short value in two's complement binary form, C<2>.
 
-=head1 FUNCTIONS
+=head2 SIZE
 
+B<sub SIZE() : int>
+
+The number of bits used to represent a short value in two's complement binary form, C<16>.
